@@ -3,18 +3,13 @@ package Lemonldap::NG::Common::Conf::SOAP;
 use strict;
 use SOAP::Lite;
 
-our $VERSION = '0.99.1';
-
-#parameter proxy Url of SOAP service
-#parameter proxyOptions SOAP::Lite parameters
+our $VERSION = 0.2;
 
 BEGIN {
     *Lemonldap::NG::Common::Conf::_soapCall = \&_soapCall;
-    *Lemonldap::NG::Common::Conf::_connect  = \&_connect;
-
+    *Lemonldap::NG::Common::Conf::_connect = \&_connect;
     sub SOAP::Transport::HTTP::Client::get_basic_credentials {
-        return $Lemonldap::NG::Common::Conf::SOAP::username =>
-          $Lemonldap::NG::Common::Conf::SOAP::password;
+       return $Lemonldap::NG::Common::Conf::SOAP::username => $Lemonldap::NG::Common::Conf::SOAP::password;
     }
 }
 
@@ -23,8 +18,7 @@ our ( $username, $password ) = ( '', '' );
 sub prereq {
     my $self = shift;
     unless ( $self->{proxy} ) {
-        $Lemonldap::NG::Common::Conf::msg =
-          '"proxy" parameter is required in "SOAP" configuration type';
+        $Lemonldap::NG::Common::Conf::msg = '"proxy" parameter is required in "SOAP" configuration type';
         return 0;
     }
     1;
@@ -37,7 +31,7 @@ sub _connect {
     if ( $self->{proxyOptions} ) {
         push @args, %{ $self->{proxyOptions} };
     }
-    $self->{ns} ||= 'urn:/Lemonldap/NG/Common/CGI/SOAPService';
+    $self->{ns} ||= 'urn:/Lemonldap/NG/Manager/SOAPService/Config';
     return $self->{service} = SOAP::Lite->ns( $self->{ns} )->proxy(@args);
 }
 
@@ -46,12 +40,7 @@ sub _soapCall {
     my $func = shift;
     $username = $self->{User};
     $password = $self->{Password};
-    my $r = $self->_connect->$func(@_);
-    if ( $r->fault() ) {
-        print STDERR "SOAP error : " . $r->fault()->{faultstring};
-        return ();
-    }
-    return $r->result;
+    return $self->_connect->$func(@_)->result;
 }
 
 sub available {
@@ -87,7 +76,7 @@ sub store {
 
 sub load {
     my $self = shift;
-    return $self->_soapCall( 'getConfig', @_ );
+    return $self->_soapCall( 'load', @_ );
 }
 
 1;
@@ -95,8 +84,6 @@ __END__
 
 =head1 NAME
 
-=encoding utf8
-
 Lemonldap::NG::Common::Conf::SOAP - Perl extension written to access to
 Lemonldap::NG Web-SSO configuration via SOAP.
 
@@ -118,7 +105,7 @@ Lemonldap::NG Web-SSO configuration via SOAP.
       },
       configStorage       => {
                 type     => 'SOAP',
-                proxy    => 'http://auth.example.com/index.pl/config',
+                proxy    => 'http://manager.example.com/soapserver.pl',
                 # If soapserver is protected by HTTP Basic:
                 User     => 'http-user',
                 Password => 'pass',
@@ -133,7 +120,7 @@ Lemonldap::NG Web-SSO configuration via SOAP.
   my $portal = Lemonldap::NG::Portal::SharedConf->new ( {
           configStorage => {
                   type    => 'SOAP',
-                  proxy    => 'http://auth.example.com/index.pl/config',
+                  proxy   => 'http://localhost/devel/test.pl',
                   # If soapserver is protected by HTTP Basic:
                   User     => 'http-user',
                   Password => 'pass',
@@ -151,7 +138,7 @@ Lemonldap::NG Web-SSO configuration via SOAP.
        {
            configStorage=>{
                   type  => 'SOAP',
-                  proxy    => 'http://auth.example.com/index.pl/config',
+                  proxy => 'http://localhost/devel/test.pl'
                   # If soapserver is protected by HTTP Basic:
                   User     => 'http-user',
                   Password => 'pass',
@@ -164,8 +151,14 @@ Lemonldap::NG Web-SSO configuration via SOAP.
 
 =head2 Server side
 
-You just have to set "Soap => 1" in your portal. See HTML documentation for
-more.
+See L<Lemonldap::NG::Common::Conf::SOAP> for documentation on client side.
+
+  use Lemonldap::NG::Manager::SOAPServer;
+  Lemonldap::NG::Manager::SOAPServer->start(
+                configStorage => {
+                        type=>"File",
+                        dirName=>"/usr/share/doc/lemonldap-ng/examples/conf/"
+                }
 
 =head1 DESCRIPTION
 
@@ -200,7 +193,7 @@ Examples :
       },
       configStorage       => {
                 type  => 'SOAP',
-                proxy => 'http://auth.example.com/index.pl/config',
+                proxy => 'http://manager.example.com/soapserver.pl',
                 User     => 'http-user',
                 Password => 'pass',
       },
@@ -228,7 +221,7 @@ set environment variables.
       },
       configStorage       => {
                 type  => 'SOAP',
-                proxy => 'http://auth.example.com/index.pl/config',
+                proxy => 'http://manager.example.com/soapserver.pl',
       },
       https               => 1,
   } );
@@ -237,7 +230,7 @@ set environment variables.
 
 =head1 SEE ALSO
 
-L<Lemonldap::NG::Common::Conf::SOAP>,
+L<Lemonldap::NG::Manager>, L<Lemonldap::NG::Common::Conf::SOAP>,
 L<Lemonldap::NG::Handler>, L<Lemonldap::NG::Portal>,
 http://wiki.lemonldap.objectweb.org/xwiki/bin/view/NG/Presentation
 
